tlslite.utils.pycrypto_rc4.PyCrypto_RC4

Package tlslite :: Package utils :: Module pycrypto_rc4 :: Class PyCrypto_RC4 |
[hide private]
[frames] | no frames]

# Class PyCrypto_RC4

source code

    rc4.RC4 --+
              |
             PyCrypto_RC4

Instance Methods | [hide private]
__init__(self, key) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintext) | source code

Method Details | [hide private]

### __init__(self, key) (Constructor) | source code
Overrides: rc4.RC4.__init__

### decrypt(self, ciphertext) | source code
Overrides: rc4.RC4.decrypt

### encrypt(self, plaintext) | source code
Overrides: rc4.RC4.encrypt